@@ -76,6 +76,7 @@ sub get {
 						'page-down' => 'Kephra::Edit::selection_move_page_down()',
 					}
 				},
+				'string-copy' => 'Kephra::Edit::string_copy()',
 				selection => {
 					convert => {
 						uppercase => 'Kephra::Edit::Convert::upper_case()',
@@ -858,12 +859,13 @@ sub get {
 						'page-down' => 'ctrl+alt+pgdn',
 					},
 				},
+				'string-copy' => 'ctrl+alt+c',
 				selection => {
 					comment => {
 						'add-perl' => 'ctrl+k',
 						'del-perl' => 'ctrl+shift+k',
-						'add-xml' => 'ctrl+h',
-						'del-xml' => 'ctrl+shift+h',
+						'add-xml' => 'ctrl+i',
+						'del-xml' => 'ctrl+shift+i',
 					},
 					format => {
 						'block-on-right-margin' => 'ctrl+shift+b',
@@ -981,9 +983,9 @@ sub get {
 				editpanel => {
 					'fold-toggle' => {
 						all => 'alt+shift+plus',
-						here => 'alt+minus',
+						here => 'ctrl+plus',
 						level => 'alt+plus',
-						recursively => 'alt+shift+minus',
+						recursively => 'ctrl+shift+plus',
 					},
 					maximize => 'shift+f11',
 				},
